@@ -1,10 +1,10 @@
-# $Id: Handel.pm 880 2005-10-03 23:00:43Z claco $
+# $Id: Handel.pm 890 2005-10-06 01:29:05Z claco $
 package Handel;
 use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.25';
+$VERSION = '0.26';
 
 BEGIN {
     use Handel::ConfigReader;
@@ -290,6 +290,16 @@ This keeps me honest and makes sure I always C<use strict>.
 
 =back
 
+=head1 CAVEATS
+
+When using item_class to specify the item class returned from add/items in your
+subclass under Class::DBI < 3.0.8, the item_class specified will be returned from
+all cart classes, including Handel::Cart itself. In most cases, people are only
+using one subclass of Handel::Cart so this won't effect them.
+
+If you plan on using multiple subclasses of Handel::Cart that may or may not
+return custom items, upgrade your Class::DBI to version 3.0.8 or greater.
+
 =head1 SEE ALSO
 
 L<Handel::Cart>
