@@ -1,4 +1,4 @@
-# $Id: DBI.pm 830 2005-09-17 23:40:59Z claco $
+# $Id: DBI.pm 887 2005-10-05 00:19:13Z claco $
 package Handel::DBI;
 use strict;
 use warnings;
@@ -40,7 +40,7 @@ sub _croak {
             -details =>
             join(' ' . translate('has invalid value') . ', ', keys %$data)
         );
-    } elsif ($method eq 'create') {
+    } elsif ($method =~ /(create|insert)/i) {
         my $details;
 
         if ($message =~ /insert new.*column\s+(.*)\s+is not unique/) {
@@ -72,6 +72,16 @@ sub has_wildcard {
     return undef;
 };
 
+sub insert {
+    my ($self, $data) = @_;
+
+    if (Class::DBI->can('insert')) {
+        return $self->SUPER::insert($data);
+    } else {
+        return $self->SUPER::create($data);
+    };
+};
+
 sub uuid {
     my $uuidstring = Handel::newuuid;
 
